@@ -476,6 +476,9 @@ def from_arrow(
     This operation will be zero copy for the most part. Types that are not
     supported by Polars may be cast to the closest supported type.
 
+    Hint: You can also directly pass arrow tables to `pl.DataFrame()` / arrow
+    arrays to `pl.Series()` if the output type is known to avoid typing issues.
+
     Parameters
     ----------
     data : :class:`pyarrow.Table`, :class:`pyarrow.Array`, one or more :class:`pyarrow.RecordBatch`
@@ -613,7 +616,7 @@ def from_pandas(
     schema_overrides: SchemaDict | None = ...,
     rechunk: bool = ...,
     nan_to_null: bool = ...,
-    include_index: Literal[True] = ...,
+    include_index: Literal[True],
 ) -> DataFrame: ...
 
 
