@@ -1,14 +1,14 @@
 from __future__ import annotations
 
 import copy
-import warnings
 from collections.abc import Collection, Sequence
 from typing import TYPE_CHECKING, Any, Callable
 
 import polars._reexport as pl
+from polars import exceptions
 from polars import functions as F
 from polars._utils.parse import parse_into_expression
-from polars._utils.various import find_stacklevel
+from polars._utils.various import issue_warning
 from polars._utils.wrap import wrap_expr
 
 if TYPE_CHECKING:
@@ -188,17 +188,19 @@ class ExprListNameSpace:
             raise ValueError(msg)
 
         if fraction is not None:
-            fraction = parse_into_expression(fraction)
+            fraction_pyexpr = parse_into_expression(fraction)
             return wrap_expr(
                 self._pyexpr.list_sample_fraction(
-                    fraction, with_replacement, shuffle, seed
+                    fraction_pyexpr, with_replacement, shuffle, seed
                 )
             )
 
         if n is None:
             n = 1
-        n = parse_into_expression(n)
-        return wrap_expr(self._pyexpr.list_sample_n(n, with_replacement, shuffle, seed))
+        n_pyexpr = parse_into_expression(n)
+        return wrap_expr(
+            self._pyexpr.list_sample_n(n_pyexpr, with_replacement, shuffle, seed)
+        )
 
     def sum(self) -> Expr:
         """
@@ -552,8 +554,8 @@ class ExprListNameSpace:
         │ [1, 2]    ┆ 1    │
         └───────────┴──────┘
         """
-        index = parse_into_expression(index)
-        return wrap_expr(self._pyexpr.list_get(index, null_on_oob))
+        index_pyexpr = parse_into_expression(index)
+        return wrap_expr(self._pyexpr.list_get(index_pyexpr, null_on_oob))
 
     def gather(
         self,
@@ -592,8 +594,8 @@ class ExprListNameSpace:
         │ [1, 2, … 5] ┆ [1, 5]       │
         └─────────────┴──────────────┘
         """
-        indices = parse_into_expression(indices)
-        return wrap_expr(self._pyexpr.list_gather(indices, null_on_oob))
+        indices_pyexpr = parse_into_expression(indices)
+        return wrap_expr(self._pyexpr.list_gather(indices_pyexpr, null_on_oob))
 
     def gather_every(
         self,
@@ -635,9 +637,9 @@ class ExprListNameSpace:
         │ [9, 10, … 12] ┆ 3   ┆ 0      ┆ [9, 12]      │
         └───────────────┴─────┴────────┴──────────────┘
         """
-        n = parse_into_expression(n)
-        offset = parse_into_expression(offset)
-        return wrap_expr(self._pyexpr.list_gather_every(n, offset))
+        n_pyexpr = parse_into_expression(n)
+        offset_pyexpr = parse_into_expression(offset)
+        return wrap_expr(self._pyexpr.list_gather_every(n_pyexpr, offset_pyexpr))
 
     def first(self) -> Expr:
         """
@@ -712,8 +714,8 @@ class ExprListNameSpace:
         │ [1, 2]    ┆ true     │
         └───────────┴──────────┘
         """
-        item = parse_into_expression(item, str_as_lit=True)
-        return wrap_expr(self._pyexpr.list_contains(item, nulls_equal))
+        item_pyexpr = parse_into_expression(item, str_as_lit=True)
+        return wrap_expr(self._pyexpr.list_contains(item_pyexpr, nulls_equal))
 
     def join(self, separator: IntoExprColumn, *, ignore_nulls: bool = True) -> Expr:
         """
@@ -764,8 +766,8 @@ class ExprListNameSpace:
         │ ["x", "y"]      ┆ _         ┆ x_y   │
         └─────────────────┴───────────┴───────┘
         """
-        separator = parse_into_expression(separator, str_as_lit=True)
-        return wrap_expr(self._pyexpr.list_join(separator, ignore_nulls))
+        separator_pyexpr = parse_into_expression(separator, str_as_lit=True)
+        return wrap_expr(self._pyexpr.list_join(separator_pyexpr, ignore_nulls))
 
     def arg_min(self) -> Expr:
         """
@@ -920,8 +922,8 @@ class ExprListNameSpace:
         │ [4, 5]    ┆ [null, null]    │
         └───────────┴─────────────────┘
         """
-        n = parse_into_expression(n)
-        return wrap_expr(self._pyexpr.list_shift(n))
+        n_pyexpr = parse_into_expression(n)
+        return wrap_expr(self._pyexpr.list_shift(n_pyexpr))
 
     def slice(
         self, offset: int | str | Expr, length: int | str | Expr | None = None
@@ -951,9 +953,9 @@ class ExprListNameSpace:
         │ [10, 2, 1]  ┆ [2, 1]    │
         └─────────────┴───────────┘
         """
-        offset = parse_into_expression(offset)
-        length = parse_into_expression(length)
-        return wrap_expr(self._pyexpr.list_slice(offset, length))
+        offset_pyexpr = parse_into_expression(offset)
+        length_pyexpr = parse_into_expression(length)
+        return wrap_expr(self._pyexpr.list_slice(offset_pyexpr, length_pyexpr))
 
     def head(self, n: int | str | Expr = 5) -> Expr:
         """
@@ -1003,8 +1005,8 @@ class ExprListNameSpace:
         │ [10, 2, 1]  ┆ [2, 1]    │
         └─────────────┴───────────┘
         """
-        n = parse_into_expression(n)
-        return wrap_expr(self._pyexpr.list_tail(n))
+        n_pyexpr = parse_into_expression(n)
+        return wrap_expr(self._pyexpr.list_tail(n_pyexpr))
 
     def explode(self) -> Expr:
         """
@@ -1065,8 +1067,8 @@ class ExprListNameSpace:
         │ [4, 4]      ┆ 0              │
         └─────────────┴────────────────┘
         """
-        element = parse_into_expression(element, str_as_lit=True)
-        return wrap_expr(self._pyexpr.list_count_matches(element))
+        element_pyexpr = parse_into_expression(element, str_as_lit=True)
+        return wrap_expr(self._pyexpr.list_count_matches(element_pyexpr))
 
     def to_array(self, width: int) -> Expr:
         """
@@ -1103,11 +1105,9 @@ class ExprListNameSpace:
 
     def to_struct(
         self,
-        n_field_strategy: ListToStructWidthStrategy = "first_non_null",
+        n_field_strategy: ListToStructWidthStrategy | None = None,
         fields: Sequence[str] | Callable[[int], str] | None = None,
         upper_bound: int | None = None,
-        *,
-        _eager: bool = False,
     ) -> Expr:
         """
         Convert the Series of type `List` to a Series of type `Struct`.
@@ -1115,45 +1115,30 @@ class ExprListNameSpace:
         Parameters
         ----------
         n_field_strategy : {'first_non_null', 'max_width'}
-            Strategy to determine the number of fields of the struct.
-
-            * "first_non_null": set number of fields equal to the length of the
-              first non zero-length sublist.
-            * "max_width": set number of fields as max length of all sublists.
+            Deprecated and ignored.
         fields
             If the name and number of the desired fields is known in advance
             a list of field names can be given, which will be assigned by index.
             Otherwise, to dynamically assign field names, a custom function can be
             used; if neither are set, fields will be `field_0, field_1 .. field_n`.
         upper_bound
-            A polars `LazyFrame` needs to know the schema at all times, so the
-            caller must provide an upper bound of the number of struct fields that
-            will be created; if set incorrectly, subsequent operations may fail.
-            (For example, an `all().sum()` expression will look in the current
-            schema to determine which columns to select).
+            A polars expression needs to be able to evaluate the output datatype at all
+            times, so the caller must provide an upper bound of the number of struct
+            fields that will be created if `fields` is not a sequence of field names.
 
-            When operating on a `DataFrame`, the schema does not need to be
-            tracked or pre-determined, as the result will be eagerly evaluated,
-            so you can leave this parameter unset.
-
-        Notes
-        -----
-        It is recommended to set 'upper_bound' to the correct output size of the struct.
-        If this is not set, Polars will not know the output type of this operation and
-        will set it to 'Unknown' which can lead to errors because Polars is not able
-        to resolve the query.
-
-        For performance reasons, the length of the first non-null sublist is used
-        to determine the number of output fields. If the sublists can be of different
-        lengths then `n_field_strategy="max_width"` must be used to obtain the expected
-        result.
+        .. versionchanged: 1.33.0
+            The `n_field_strategy` parameter is ignored and deprecated. The `fields`
+            needs to be a sequence of field names or the upper bound is regarded as
+            ground truth.
 
         Examples
         --------
         Convert list to struct with default field name assignment:
 
         >>> df = pl.DataFrame({"n": [[0, 1], [0, 1, 2]]})
-        >>> df.with_columns(struct=pl.col("n").list.to_struct())  # doctest: +SKIP
+        >>> df.with_columns(
+        ...     struct=pl.col("n").list.to_struct(upper_bound=2)
+        ... )  # doctest: +SKIP
         shape: (2, 2)
         ┌───────────┬───────────┐
         │ n         ┆ struct    │
@@ -1164,28 +1149,12 @@ class ExprListNameSpace:
         │ [0, 1, 2] ┆ {0,1}     │ # NOT OK - last value missing
         └───────────┴───────────┘
 
-        As the shorter sublist comes first, we must use the `max_width`
-        strategy to force a search for the longest.
-
-        >>> df.with_columns(
-        ...     struct=pl.col("n").list.to_struct(n_field_strategy="max_width")
-        ... )  # doctest: +SKIP
-        shape: (2, 2)
-        ┌───────────┬────────────┐
-        │ n         ┆ struct     │
-        │ ---       ┆ ---        │
-        │ list[i64] ┆ struct[3]  │ # <- struct with 3 fields
-        ╞═══════════╪════════════╡
-        │ [0, 1]    ┆ {0,1,null} │ # OK
-        │ [0, 1, 2] ┆ {0,1,2}    │ # OK
-        └───────────┴────────────┘
-
         Convert list to struct with field name assignment by function/index:
 
         >>> df = pl.DataFrame({"n": [[0, 1], [2, 3]]})
-        >>> df.select(pl.col("n").list.to_struct(fields=lambda idx: f"n{idx}")).rows(
-        ...     named=True
-        ... )  # doctest: +SKIP
+        >>> df.select(
+        ...     pl.col("n").list.to_struct(fields=lambda idx: f"n{idx}", upper_bound=2)
+        ... ).rows(named=True)  # doctest: +SKIP
         [{'n': {'n0': 0, 'n1': 1}}, {'n': {'n0': 2, 'n1': 3}}]
 
         Convert list to struct with field name assignment by index from a list of names:
@@ -1195,19 +1164,23 @@ class ExprListNameSpace:
         ... )
         [{'n': {'one': 0, 'two': 1}}, {'n': {'one': 2, 'two': 3}}]
         """
-        if isinstance(fields, Sequence):
-            pyexpr = self._pyexpr.list_to_struct_fixed_width(fields)
-            return wrap_expr(pyexpr)
-        else:
-            if not _eager:
-                msg = (
-                    "`to_struct()` should be passed a list of field names to avoid "
-                    "query errors in subsequent operations (e.g. <struct operation> "
-                    "not supported for dtype Unknown)"
-                )
-                warnings.warn(msg, stacklevel=find_stacklevel())
-            pyexpr = self._pyexpr.list_to_struct(n_field_strategy, fields, upper_bound)
-            return wrap_expr(pyexpr)
+        if n_field_strategy is not None:
+            issue_warning(
+                "`Expr.list.to_struct` with `n_field_strategy` is deprecated and has no effect on execution.",
+                DeprecationWarning,
+            )
+
+        if not isinstance(fields, Sequence):
+            if upper_bound is None:
+                msg = "`Expr.list.to_struct` requires either `fields` to be a sequence or `upper_bound` to be set.\n\nThis used to be allowed but produced unpredictable results."
+                raise exceptions.InvalidOperationError(msg)
+
+            if fields is None:
+                fields = [f"field_{i}" for i in range(upper_bound)]
+            else:
+                fields = [fields(i) for i in range(upper_bound)]
+
+        return wrap_expr(self._pyexpr.list_to_struct(fields))
 
     def eval(self, expr: Expr, *, parallel: bool = False) -> Expr:
         """
@@ -1309,10 +1282,10 @@ class ExprListNameSpace:
         if isinstance(other, Collection) and not isinstance(other, str):
             if not isinstance(other, (Sequence, pl.Series, pl.DataFrame)):
                 other = list(other)  # eg: set, frozenset, etc
-            other = F.lit(other)._pyexpr
+            other_pyexpr = F.lit(other)._pyexpr
         else:
-            other = parse_into_expression(other)
-        return wrap_expr(self._pyexpr.list_set_operation(other, "union"))
+            other_pyexpr = parse_into_expression(other)
+        return wrap_expr(self._pyexpr.list_set_operation(other_pyexpr, "union"))
 
     def set_difference(self, other: IntoExpr | Collection[Any]) -> Expr:
         """
@@ -1351,10 +1324,10 @@ class ExprListNameSpace:
         if isinstance(other, Collection) and not isinstance(other, str):
             if not isinstance(other, (Sequence, pl.Series, pl.DataFrame)):
                 other = list(other)  # eg: set, frozenset, etc
-            other = F.lit(other)._pyexpr
+            other_pyexpr = F.lit(other)._pyexpr
         else:
-            other = parse_into_expression(other)
-        return wrap_expr(self._pyexpr.list_set_operation(other, "difference"))
+            other_pyexpr = parse_into_expression(other)
+        return wrap_expr(self._pyexpr.list_set_operation(other_pyexpr, "difference"))
 
     def set_intersection(self, other: IntoExpr | Collection[Any]) -> Expr:
         """
@@ -1389,10 +1362,10 @@ class ExprListNameSpace:
         if isinstance(other, Collection) and not isinstance(other, str):
             if not isinstance(other, (Sequence, pl.Series, pl.DataFrame)):
                 other = list(other)  # eg: set, frozenset, etc
-            other = F.lit(other)._pyexpr
+            other_pyexpr = F.lit(other)._pyexpr
         else:
-            other = parse_into_expression(other)
-        return wrap_expr(self._pyexpr.list_set_operation(other, "intersection"))
+            other_pyexpr = parse_into_expression(other)
+        return wrap_expr(self._pyexpr.list_set_operation(other_pyexpr, "intersection"))
 
     def set_symmetric_difference(self, other: IntoExpr | Collection[Any]) -> Expr:
         """
@@ -1427,7 +1400,9 @@ class ExprListNameSpace:
         if isinstance(other, Collection) and not isinstance(other, str):
             if not isinstance(other, (Sequence, pl.Series, pl.DataFrame)):
                 other = list(other)  # eg: set, frozenset, etc
-            other = F.lit(other)._pyexpr
+            other_pyexpr = F.lit(other)._pyexpr
         else:
-            other = parse_into_expression(other)
-        return wrap_expr(self._pyexpr.list_set_operation(other, "symmetric_difference"))
+            other_pyexpr = parse_into_expression(other)
+        return wrap_expr(
+            self._pyexpr.list_set_operation(other_pyexpr, "symmetric_difference")
+        )
