@@ -3,7 +3,12 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Literal
 
 if TYPE_CHECKING:
-    from polars._typing import ColumnMapping, DeletionFiles, SchemaDict
+    from polars._typing import (
+        ColumnMapping,
+        DefaultFieldValues,
+        DeletionFiles,
+        SchemaDict,
+    )
     from polars.io.cloud.credential_provider._builder import CredentialProviderBuilder
     from polars.io.scan_options.cast_options import ScanCastOptions
 
@@ -45,4 +50,5 @@ class ScanOptions:
     retries: int = 2
 
     column_mapping: ColumnMapping | None = None
+    default_values: DefaultFieldValues | None = None
     deletion_files: DeletionFiles | None = None
